package images;

import java.awt.Image;

import javax.swing.BoundedRangeModel;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

public class ImagePane extends JScrollPane implements ChangeListener{
    
    //Panel se prikazuje u okviru ImagePane komponente, koja mu sluzi 
    //samo kao okvir, JPanel je za sadrzaj
    JPanel content;
    //Koristimo labelu na koju cemo zalepiti ikonicu i razvuci je po
    //celom panelu kao nacin za predstavljanje slike
    JLabel contentLabel;
    ImageIcon imageIcon;
    //cuvamo original sliku, koja ostaje nepromenjena nakon skaliranja,
    //kako ne bi izgubili etalon prema kojem skaliramo
    Image original;
    
    public ImagePane(Image source) {
	this.original=source;
	content=new JPanel();
	/*redirekcija prikaza JPanel-a na 
	 * ovaj scroll pane
	 */
	setViewportView(content);
	imageIcon=new ImageIcon(source);
	contentLabel=new JLabel(imageIcon);
	content.add(contentLabel);
    }
    
    @Override
    public void stateChanged(ChangeEvent e) {
	//e.getSource vraca lokaciju odakle je dosao event, u ovom slucaju
	//mi znamo da je to mogao da bude samo BoundedRangeModel, pa 
	//smemo da ga kastujemo eksplicitno
	    BoundedRangeModel model=(BoundedRangeModel)e.getSource();
	    //da bi odredili stepen potrebnog skaliranja, dovoljno je 
	    //da znamo min, max i trenutnu vrednost, posle samo normalizujemo
	    //na interval [0,1]
	    int val=model.getValue();
	    int min=model.getMinimum();
	    int max=model.getMaximum();
	    double scaleFactor=(val*1.0-min)/(max-min);
	    //ugradjena funkcija za skaliranje
	    Image newimg=original.getScaledInstance((int)(scaleFactor*original.getWidth(null)), 
		(int)(scaleFactor*original.getHeight(null)), Image.SCALE_FAST);
	    //postavljamo skaliranu kopiju na ikonicu labele
	    imageIcon.setImage(newimg);
	    content.repaint();
    }
}
