package images;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.Image;
import java.awt.Toolkit;

import javax.swing.BoundedRangeModel;
import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSlider;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

public class TwoImagesGUI extends JFrame {

    int width=500;
    int height=500;
    
    //pomocni paneli, cija je jedina namena
    //da lakse organizujemo layout (kompozitni layout)
    JPanel infoPanel;
    JPanel imagePanel;
    JPanel sliderPanel;
    //labele za prikaz procenta skaliranja
    JLabel info1;
    JLabel info2;
    //kontrole ciji je model podataka vrlo jednostavan
    //min, max i value
    JSlider slider1;
    JSlider slider2;
    //dodatna klasa koja predstavlja nasledjeni scrollpane
    //u koji ubacujemo sliku za skaliranje
    ImagePane img1;
    ImagePane img2;
    
    public TwoImagesGUI() {
	
	setPreferredSize(new Dimension(width, height));
	center();
	
	/*NOVO u odnosu na osnovi GUI*/
	//inicijalno na 100%, posto smo sliku
	//na startu ucitali u orignialnoj dimenziji
	slider1=new JSlider(0,100,100);
	slider2=new JSlider(0,100,100);
	//organizujemo kompozitni layout koriscenjem
	//pomocnih panela
	setLayout(new BorderLayout());
	infoPanel=new JPanel();
	//u okviru svakog od pomocnih panela definisemo
	//gridlayout sa jednim redom i dve kolone (organizuje
	//komponente u tabelarnoj formi)
	infoPanel.setLayout(new GridLayout(1,2));
	getContentPane().add(infoPanel, BorderLayout.NORTH);
	info1=new JLabel("100%");
	info2=new JLabel("100%");
	infoPanel.add(info1);
	infoPanel.add(info2);
	//dodajemo osluskivace dogadjaja koji se ispaljuju od strane 
	//slider modela. Dakle ovo je taj momenat pretplacivanja na dogadjaj
	//(subscribe). Tek sada onaj koji slusa dogadjaj ce moci i da 
	//reaguje na njega. U ovoj aplikaciji osluskivaci promene slider
	//modela podataka su kako labele (jer prikazuju procenat skaliranja)
	//, tako i same slike, jer je potrebno da se prikazu u novoj dimenziji
	//primeniti kako je na ovaj nacin razdvojen gui od podataka i kontrole
	slider1.getModel().addChangeListener(new InfoListener(info1));
	slider2.getModel().addChangeListener(new InfoListener(info2));
	
	imagePanel=new JPanel();
	imagePanel.setLayout(new GridLayout(1,2));
	getContentPane().add(imagePanel, BorderLayout.CENTER);
	
	ImageIcon imgicon=new ImageIcon("Sunset.jpg");
	Image source=imgicon.getImage();
	//prosledjujemo klasi imagepane samo source slike,
	//koji ce posle biti sacuvan kao originalna informacija
	//u svakoj od imagepane instanci. Na taj nacin promena,
	//tj. skaliranje jedne slike, nece uticati na velicinu druge.
	img1=new ImagePane(source);
	slider1.getModel().addChangeListener(img1);
	img2=new ImagePane(source);
	slider2.getModel().addChangeListener(img2);
	imagePanel.add(img1);
	imagePanel.add(img2);
	
	sliderPanel=new JPanel();
	sliderPanel.setLayout(new GridLayout(1,2));
	getContentPane().add(sliderPanel, BorderLayout.SOUTH);
	sliderPanel.add(slider1);
	sliderPanel.add(slider2);
	
	pack();
	setDefaultCloseOperation(EXIT_ON_CLOSE);
	setVisible(true);
    }
    
    class InfoListener implements ChangeListener{
	JLabel lab;
	public InfoListener(JLabel lab) {
	    this.lab=lab;
	}
	
	@Override
	public void stateChanged(ChangeEvent e) {
	 
	    BoundedRangeModel model=(BoundedRangeModel)e.getSource();
	    int val=model.getValue();
	    int min=model.getMinimum();
	    int max=model.getMaximum();
	    long perc=Math.round((val*1.0-min)/(max-min)*100);
	    lab.setText(perc+"%");
	}
    }
    
    /**
     * @param args
     */
    public static void main(String[] args) {
	TwoImagesGUI gui=new TwoImagesGUI();
    }
    
    void center(){
	Dimension d=Toolkit.getDefaultToolkit().getScreenSize();
	setLocation((d.width-width)/2, (d.height-height)/2);
    }

}
